CameraDescription class
Represents a camera device available on the platform.
- Annotations
-
- @freezed
Constructors
- CameraDescription({required String id, required String label, @Default.new(LensDirection.unknown) @LensDirectionConverter.new() LensDirection lensDirection, @Default.new(90) int sensorOrientation})
-
Constructs a new instance of CameraDescription.
constfactory
- CameraDescription.fromHelpLib(CameraDescription camera)
-
factory
- CameraDescription.fromJs(List devices, dynamic device)
-
factory
-
CameraDescription.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $CameraDescriptionCopyWith<
CameraDescription> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
Unique identifier for the camera.
no setterinherited
- label → String
-
A user-friendly name or description of the camera.
no setterinherited
- lensDirection → LensDirection
-
The direction that the camera's lens is facing.
This can be 'front', 'back', etc.
Might be
nullif the lens direction is unknown or not specified.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sensorOrientation → int
-
Clockwise angle through which the output image needs to be rotated to be upright on the device screen in its native orientation.
no setterinherited
- toHelpLib → CameraDescription
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override